@@ -1,7 +1,7 @@
 /*
  * wavemon - a wireless network monitoring aplication
  *
- * Copyright (c) 2001 Jan Morgenstern <jan@jm-music.de>
+ * Copyright (c) 2001-2002 Jan Morgenstern <jan@jm-music.de>
  *
  * wavemon is free software; you can redistribute it and/or modify it under 
  * the terms of the GNU General Public License as published by the Free 
@@ -60,6 +60,8 @@ void waddstr_item(WINDOW *w, int y, struct conf_item *item, char hilight)
 							break;
 			case t_list:	strncpy(s, ll_get(item->list, *(int *)item->v), 32);
 							break;
+			case t_listval:	strncpy(s, (char *)item->v, 32);
+							break;
 			case t_sep:		/* gcc -Wall sucks */
 			case t_func:
 		}
@@ -96,7 +98,8 @@ void waddstr_item(WINDOW *w, int y, struct conf_item *item, char hilight)
 void change_item(int inum, char sign, char accel)
 {
 	struct conf_item *item = ll_get(conf_items, inum);
-	
+	int tmp;
+		
 	switch (item->type) {
 		case t_int:		if (!accel) {
 							if (*(long int *)item->v + item->inc * sign <= item->max && 
@@ -119,6 +122,19 @@ void change_item(int inum, char sign, char accel)
 						if (*(long int *)item->v >= ll_size(item->list)) *(long int *)item->v = 0;
 							else if (*(long int *)item->v < 0) *(long int *)item->v = ll_size(item->list) - 1;
 						break;
+		case t_listval:	tmp = ll_scan(item->list, "s", (char *)item->v);
+						if (tmp == -1) {
+							tmp = 0;
+						} else {
+							tmp += sign;
+							if (tmp >= ll_size(item->list)) {
+								tmp = 0;
+							} else if (tmp < 0) {
+								tmp = ll_size(item->list) - 1;
+							}
+						}
+						strncpy((char *)item->v, ll_get(item->list, tmp), 32);
+						break;
 		case t_sep:		/* gcc -Wall sucks */
 		case t_func:
 	}
